| Title: | Interactive Document for Working with Variance Analysis |
|---|---|
| Description: | An interactive document on the topic of variance analysis using 'rmarkdown' and 'shiny' packages. Runtime examples are provided in the package function as well as at <https://predanalyticssessions1.shinyapps.io/chisquareVarianceTest/>. |
| Authors: | Kartikeya Bolar |
| Maintainer: | Kartikeya Bolar <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-06-05 07:57:51 UTC |
| Source: | https://github.com/cran/VTShiny |
VTShiny() loads interactive user interface built using R 'shiny'.
VTShiny()VTShiny()
Start VTShiny
The interactive user interface is to provide an easy way for variance analysis.
Nothing
if(interactive()){ library(rmarkdown) VTShiny() }if(interactive()){ library(rmarkdown) VTShiny() }