Welcome to ClientVPS Mirrors

Help for package VTShiny
Type: Package
Title: Interactive Document for Working with Variance Analysis
Version: 0.1.0
Author: Kartikeya Bolar
Maintainer: Kartikeya Bolar <kartikeya.bolar@tapmi.edu.in>
Description: An interactive document on the topic of variance analysis using 'rmarkdown' and 'shiny' packages. Runtime examples are provided in the package function as well as at https://predanalyticssessions1.shinyapps.io/chisquareVarianceTest/.
License: GPL-2
Encoding: UTF-8
LazyData: TRUE
Depends: R (≥ 3.0.3)
Imports: shiny,rmarkdown,stats,EnvStats
RoxygenNote: 6.1.1
NeedsCompilation: no
Packaged: 2019-07-14 13:07:47 UTC; KARTIKEYA
Repository: CRAN
Date/Publication: 2019-07-18 09:08:11 UTC

Launch 'VTShiny' Interface

Description

VTShiny() loads interactive user interface built using R 'shiny'.

Usage

VTShiny()

Details

Start VTShiny

The interactive user interface is to provide an easy way for variance analysis.

Value

Nothing

Examples

if(interactive()){
library(rmarkdown)
VTShiny()
}

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.